/******************************************************************************
 * Enums.js
 *
 * Author:
 * 		Aleksandar Toplek
 *
 * Created on:
 * 		25.02.2012.
 *
 *****************************************************************************/
 
var Enums = {
	Tribes: {
		"1": "Romans",
		"2": "Teutons",
		"3": "Gauls"
	},

	/**************************************************************************
	 *
	 * List of all available pages in travian game
	 *
	 * This list doesn't cover all possibilities, it contains only main
	 * pages of game this doesn't include tabs and some subdomain pages.
	 * (eg. answers.travian.* is not listed)
	 *
	 *************************************************************************/
	TravianPages: {
		Home: "/",
		Login: "/login.php",
		Logout: "/logout.php",
		Player: "/spieler.php",

		VillageOut: "/dorf1.php",
		VillageIn: "/dorf2.php",
		VillageView: "/dorf3.php",

		Build: "/build.php",

		Map: "/karte.php",
		MapPosition: "/position_details.php",

		Statistics: "/statistiken.php",
		Reports: "/berichte.php",
		Messages: "/nachrichten.php",

		Alliance: "/allianz.php",

		HeroLook: "/hero.php",
		HeroInventory: "/hero_inventory.php",
		HeroAdventures: "/hero_adventure.php",
		HeroAuctions: "/hero_auction.php",

		Plus: "/plus.php",
		Help: "/help.php"
	},
	
	TaskTypes: {
		Build: "",
		Movements: "",
		TotalTroops: ""
	},
	
	/**************************************************************************
	 *
	 * Village out filed IDs
	 *
	 * Specifies the resource map in a village, with arrays of wood, clay, 
	 * iron and crop respectively.
	 * (eg. Enums.VillageOutMaps.fX[Y].length for number of fields,
	 *		Enums.VillageOutMaps.fX[Y][Z] for field build id where
	 *		X is type of village,
	 *		Y is filed type and 
	 *		Z is filed index)
	 *
	 * Author: Ignacio Munizaga (thagat)
	 *
	 *************************************************************************/
	VillageOutMaps: {
		f1: [[2, 13, 16], [5, 15, 17], [6, 9, 10], [0, 1, 3, 4, 7, 8, 11, 12, 14]],
		f2: [[2, 13, 16], [4, 5, 15, 17], [0, 3, 6, 9, 10], [1, 7, 8, 11, 12, 14]],
		f3: [[0, 2, 13, 16], [4, 5, 15, 17], [3, 6, 9, 10], [1, 7, 8, 11, 12, 14]],
		f4: [[0, 2, 13, 16], [3, 4, 5, 15, 17], [6, 9, 10], [1, 7, 8, 11, 12, 14]],
		f5: [[0, 2, 4, 13, 16], [5, 15, 17], [3, 6, 9, 10], [1, 7, 8, 11, 12, 14]],
		f6: [[2], [15], [3], [0, 1, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 16, 17]],
		f7: [[0, 3, 13, 16], [4, 5, 15, 17], [6, 9, 10], [1, 2, 7, 8, 11, 12, 14]],
		f8: [[3, 13, 16], [4, 5, 15, 17], [0, 6, 9, 10], [1, 2, 7, 8, 11, 12, 14]],
		f9: [[3, 4, 13, 16], [5, 15, 17], [0, 6, 9, 10], [1, 2, 7, 8, 11, 12, 14]],
		f10: [[2, 13, 16], [3, 4, 5, 15, 17], [0, 6, 9, 10], [1, 7, 8, 11, 12, 14]],
		f11: [[1, 2, 4, 12], [9, 10, 15], [0, 3, 7, 8, 11], [5, 6, 13, 14, 16, 17]],
		f12: [[0, 2, 3, 13, 16], [4, 5, 15, 17], [6, 9, 10], [1, 7, 8, 11, 12, 14]],
	},
	
	VillageInGID: {
		1: 'Woodcutter',
		2: 'ClayPit',
		3: 'IronMine',
		4: 'Cropland',
		5: 'Sawmill',
		6: 'Brickyard',
		7: 'IronFoundry',
		8: 'GrainMill',
		9: 'Bakery',
		10: 'Warehouse',
		11: 'Granary',
		13: 'Smithy',
		14: 'TournamentSquare',
		15: 'MainBuilding',
		16: 'RallyPoint',
		17: 'Marketplace',
		18: 'Embassy',
		19: 'Barracks',
		20: 'Stable',
		21: 'Workshop',
		22: 'Academy',
		23: 'Cranny',
		24: 'TownHall',
		25: 'Residence',
		26: 'Palace',
		27: 'Treasury',
		28: 'TradeOffice',
		29: 'GreatBarracks',
		30: 'GreatStable',
		31: 'CityWall',
		32: 'EarthWall',
		33: 'Palisade',
		34: 'StonemasonsLodge',
		35: 'Brewery',
		36: 'Trapper',
		37: 'HerosMansion',
		38: 'GreatWarehouse',
		39: 'GreatGranary',
		40: 'WonderoftheWorld',
		41: 'HorseDrinkingTrough'
	},

	FieldNames: [ "Lumber", "Clay", "Iron", "Crop" ],

	/**************************************************************************
	 *
	 * Fields constants
	 *
	 * lvl#: [wood, clay, iron, crop, consumption, time, culture points, production]
	 *
	 *************************************************************************/
	Fields: [
		[ // Woood
			[40, 100, 50, 60, 2, 260, 1, 5],
			[65, 165, 85, 100, 1, 620, 1, 9],
			[110, 280, 140, 165, 1, 1190, 2, 15],
			[185, 465, 235, 280, 1, 2100, 2, 22],
			[310, 780, 390, 465, 1, 3560, 2, 33],
			[520, 1300, 650, 780, 2, 5890, 3, 50],
			[870, 2170, 1085, 1300, 2, 9620, 4, 70],
			[1450, 3625, 1810, 2175, 2, 15590, 4, 100],
			[2420, 6050, 3025, 3630, 2, 25150, 5, 145],
			[4040, 10105, 5050, 6060, 2, 40440, 6, 200],
			[6750, 16870, 8435, 10125, 2, 64900, 7, 280],
			[11270, 28175, 14090, 16905, 2, 104050, 9, 375],
			[18820, 47055, 23525, 28230, 2, 166680, 11, 495],
			[31430, 78580, 39290, 47150, 2, 266880, 13, 635],
			[52490, 131230, 65615, 78740, 2, 427210, 15, 800],
			[87660, 219155, 109575, 131490, 3, 683730, 18, 1000],
			[146395, 365985, 182995, 219590, 3, 1094170, 22, 1300],
			[244480, 611195, 305600, 366715, 3, 1750880, 27, 1600],
			[408280, 1020695, 510350, 612420, 3, 2801600, 32, 2000],
			[681825, 1704565, 852280, 1022740, 3, 4482770, 38, 2450],
			[1138650, 2846620, 1423310, 1707970, 3, 7172630, 46, 3050],
			[1901540, 4753855, 2376925, 2852315, 3, 11476400, 55, 3750],
			[3175575, 7938935, 3969470, 4763360, 3, 18362440, 66, 4600],
			[5303210, 13258025, 6629015, 7954815, 3, 29380110, 79, 5650],
			[8856360, 22140900, 11070450, 13284540, 3, 47008380, 95, 6950]
		],
		[ //clay
			[80, 40, 80, 50, 2, 220, 1, 5],
			[135, 65, 135, 85, 1, 550, 1, 9],
			[225, 110, 225, 140, 1, 1080, 2, 15],
			[375, 185, 375, 235, 1, 1930, 2, 22],
			[620, 310, 620, 390, 1, 3290, 2, 33],
			[1040, 520, 1040, 650, 2, 5470, 3, 50],
			[1735, 870, 1735, 1085, 2, 8950, 4, 70],
			[2900, 1450, 2900, 1810, 2, 14520, 4, 100],
			[4840, 2420, 4840, 3025, 2, 23430, 5, 145],
			[8080, 4040, 8080, 5050, 2, 37690, 6, 200],
			[13500, 6750, 13500, 8435, 2, 60510, 7, 280],
			[22540, 11270, 22540, 14090, 2, 97010, 9, 375],
			[37645, 18820, 37645, 23525, 2, 155420, 11, 495],
			[62865, 31430, 62865, 39290, 2, 248870, 13, 635],
			[104985, 52490, 104985, 65615, 2, 398390, 15, 800],
			[175320, 87660, 175320, 109575, 3, 637620, 18, 1000],
			[292790, 146395, 292790, 182995, 3, 1020390, 22, 1300],
			[488955, 244480, 488955, 305600, 3, 1632820, 27, 1600],
			[816555, 408280, 816555, 510350, 3, 2612710, 32, 2000],
			[1363650, 681825, 1363650, 852280, 3, 4180540, 38, 2450],
			[2277295, 1138650, 2277295, 1423310, 3, 6689060, 46, 3050],
			[3803085, 1901540, 3803085, 2376925, 3, 10702690, 55, 3750],
			[6351150, 3175575, 6351150, 3969470, 3, 17124500, 66, 4600],
			[10606420, 5303210, 10606420, 6629015, 3, 27399410, 79, 5650],
			[17712720, 8856360, 17712720, 11070450, 3, 43839250, 95, 6950]
		],
		[ //Iron
			[100, 80, 30, 60, 3, 450, 1, 5],
			[165, 135, 50, 100, 2, 920, 1, 9],
			[280, 225, 85, 165, 2, 1670, 2, 15],
			[465, 375, 140, 280, 2, 2880, 2, 22],
			[780, 620, 235, 465, 2, 4800, 2, 33],
			[1300, 1040, 390, 780, 2, 7880, 3, 50],
			[2170, 1735, 650, 1300, 2, 12810, 4, 70],
			[3625, 2900, 1085, 2175, 2, 20690, 4, 100],
			[6050, 4840, 1815, 3630, 2, 33310, 5, 145],
			[10105, 8080, 3030, 6060, 2, 53500, 6, 200],
			[16870, 13500, 5060, 10125, 3, 85800, 7, 280],
			[28175, 22540, 8455, 16905, 3, 137470, 9, 375],
			[47055, 37645, 14115, 28230, 3, 220160, 11, 495],
			[78580, 62865, 23575, 47150, 3, 352450, 13, 635],
			[131230, 104985, 39370, 78740, 3, 564120, 15, 800],
			[219155, 175320, 65745, 131490, 3, 902790, 18, 1000],
			[365985, 292790, 109795, 219590, 3, 1444660, 22, 1300],
			[611195, 488955, 183360, 366715, 3, 2311660, 27, 1600],
			[1020695, 816555, 306210, 612420, 3, 3698850, 32, 2000],
			[1704565, 1363650, 511370, 1022740, 3, 5918370, 38, 2450],
			[2846620, 2277295, 853985, 1707970, 4, 9469590, 46, 3050],
			[4753855, 3803085, 1426155, 2852315, 4, 15151540, 55, 3750],
			[7938935, 6351150, 2381680, 4763360, 4, 24242660, 66, 4600],
			[13258025, 10606420, 3977410, 7954815, 4, 38788450, 79, 5650],
			[22140900, 17712720, 6642270, 13284540, 4, 62061730, 95, 6950]
		],
		[ //Crop
			[70, 90, 70, 20, 0, 150, 1, 5],
			[115, 150, 115, 35, 0, 440, 1, 9],
			[195, 250, 195, 55, 0, 900, 2, 15],
			[325, 420, 325, 95, 0, 1650, 2, 22],
			[545, 700, 545, 155, 0, 2830, 2, 33],
			[910, 1170, 910, 260, 1, 4730, 3, 50],
			[1520, 1950, 1520, 435, 1, 7780, 4, 70],
			[2535, 3260, 2535, 725, 1, 12640, 4, 100],
			[4235, 5445, 4235, 1210, 1, 20430, 5, 145],
			[7070, 9095, 7070, 2020, 1, 32880, 6, 200],
			[11810, 15185, 11810, 3375, 1, 52810, 7, 280],
			[19725, 25360, 19725, 5635, 1, 84700, 9, 375],
			[32940, 42350, 32940, 9410, 1, 135710, 11, 495],
			[55005, 70720, 55005, 15715, 1, 217340, 13, 635],
			[91860, 118105, 91860, 26245, 1, 347950, 15, 800],
			[153405, 197240, 153405, 43830, 2, 556910, 18, 1000],
			[256190, 329385, 256190, 73195, 2, 891260, 22, 1300],
			[427835, 550075, 427835, 122240, 2, 1426210, 27, 1600],
			[714485, 918625, 714485, 204140, 2, 2282140, 32, 2000],
			[1193195, 1534105, 1193195, 340915, 2, 3651630, 38, 2450],
			[1992635, 2561960, 1992635, 569325, 2, 5842810, 46, 3050],
			[3327700, 4278470, 3327700, 950770, 2, 9348690, 55, 3750],
			[5557255, 7145045, 5557255, 1587785, 2, 14958110, 66, 4600],
			[9280620, 11932225, 9280620, 2651605, 2, 23933170, 79, 5650],
			[15498630, 19926810, 15498630, 4428180, 2, 38293280, 95, 6950]
		]
	],
	
	Buildings: {
		//http://t4.answers.travian.com/index.php?aid=194
		Sawmill: [
			[520, 380, 290, 90, 4, 3000, 1],
			[935, 685, 520, 160, 2, 5700, 1],
			[1685, 1230, 940, 290, 2, 9750, 2],
			[3035, 2215, 1690, 525, 2, 15830, 2],
			[5460, 3990, 3045, 945, 2, 24940, 2]
		],

		//http://t4.answers.travian.com/index.php?aid=188
		Brickyard: [
			[440, 480, 320, 50, 3, 2240, 1],
			[790, 865, 575, 90, 2, 4560, 1],
			[1425, 1555, 1035, 160, 2, 8040, 2],
			[2565, 2800, 1865, 290, 2, 13260, 2],
			[4620, 5040, 3360, 525, 2, 21090, 2]
		],

		//http://t4.answers.travian.com/index.php?aid=192
		IronFoundry: [
			[200, 450, 510, 120, 6, 4080, 1],
			[360, 810, 920, 215, 3, 7320, 1],
			[650, 1460, 1650, 390, 3, 12180, 2],
			[1165, 2625, 2975, 700, 3, 19470, 2],
			[2100, 4725, 5355, 1260, 3, 30410, 2]
		],

		//http://t4.answers.travian.com/index.php?aid=191
		GrainMill: [
			[500, 440, 380, 1240, 3, 1840, 1],
			[900, 790, 685, 2230, 2, 3960, 1],
			[1620, 1425, 1230, 4020, 2, 7140, 2],
			[2915, 2565, 2215, 7230, 2, 11910, 2],
			[5250, 4620, 3990, 13015, 2, 19070, 2]
		],

		//http://t4.answers.travian.com/index.php?aid=187
		Bakery: [
			[1200, 1480, 870, 1600, 4, 3680, 1],
			[2160, 2665, 1565, 2880, 2, 6720, 1],
			[3890, 4795, 2820, 5185, 2, 11280, 2],
			[7000, 8630, 5075, 9330, 2, 18120, 2],
			[12595, 15535, 9135, 16795, 2, 28380, 2]
		],

		//http://t4.answers.travian.com/index.php?aid=51
		Warehouse: [
			[130, 160, 90, 40, 1, 2000, 1],
			[165, 205, 115, 50, 1, 2620, 1],
			[215, 260, 145, 65, 1, 3340, 2],
			[275, 335, 190, 85, 1, 4170, 2],
			[350, 430, 240, 105, 1, 5140, 2],
			[445, 550, 310, 135, 1, 6260, 3],
			[570, 705, 395, 175, 1, 7570, 4],
			[730, 900, 505, 225, 1, 9080, 4],
			[935, 1155, 650, 290, 1, 10830, 5],
			[1200, 1475, 830, 370, 1, 12860, 6],
			[1535, 1890, 1065, 470, 2, 15220, 7],
			[1965, 2420, 1360, 605, 2, 17950, 9],
			[2515, 3095, 1740, 775, 2, 21130, 11],
			[3220, 3960, 2230, 990, 2, 24810, 13],
			[4120, 5070, 2850, 1270, 2, 29080, 15],
			[5275, 6490, 3650, 1625, 2, 34030, 18],
			[6750, 8310, 4675, 2075, 2, 39770, 22],
			[8640, 10635, 5980, 2660, 2, 46440, 27],
			[11060, 13610, 7655, 3405, 2, 54170, 32],
			[14155, 17420, 9800, 4355, 2, 63130, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=5
		Granary: [
			[80, 100, 70, 20, 1, 1600, 1],
			[100, 130, 90, 25, 1, 2160, 1],
			[130, 165, 115, 35, 1, 2800, 2],
			[170, 210, 145, 40, 1, 3550, 2],
			[215, 270, 190, 55, 1, 4420, 2],
			[275, 345, 240, 70, 1, 5420, 3],
			[350, 440, 310, 90, 1, 6590, 4],
			[450, 565, 395, 115, 1, 7950, 4],
			[575, 720, 505, 145, 1, 9520, 5],
			[740, 920, 645, 185, 1, 11340, 6],
			[945, 1180, 825, 235, 2, 13450, 7],
			[1210, 1510, 1060, 300, 2, 15910, 9],
			[1545, 1935, 1355, 385, 2, 18750, 11],
			[1980, 2475, 1735, 495, 2, 22050, 13],
			[2535, 3170, 2220, 635, 2, 25880, 15],
			[3245, 4055, 2840, 810, 2, 30320, 18],
			[4155, 5190, 3635, 1040, 2, 35470, 22],
			[5315, 6645, 4650, 1330, 2, 41450, 27],
			[6805, 8505, 5955, 1700, 2, 48380, 32],
			[8710, 10890, 7620, 2180, 2, 56420, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=76
		Smithy: [
			[180, 250, 500, 160, 4, 2000, 2],
			[230, 320, 640, 205, 2, 2620, 3],
			[295, 410, 820, 260, 2, 3340, 3],
			[375, 525, 1050, 335, 2, 4170, 4],
			[485, 670, 1340, 430, 2, 5140, 5],
			[620, 860, 1720, 550, 3, 6260, 6],
			[790, 1100, 2200, 705, 3, 7570, 7],
			[1015, 1405, 2815, 900, 3, 9080, 9],
			[1295, 1800, 3605, 1155, 3, 10830, 10],
			[1660, 2305, 4610, 1475, 3, 12860, 12],
			[2125, 2950, 5905, 1890, 3, 15220, 15],
			[2720, 3780, 7555, 2420, 3, 17950, 18],
			[3480, 4835, 9670, 3095, 3, 21130, 21],
			[4455, 6190, 12380, 3960, 3, 24810, 26],
			[5705, 7925, 15845, 5070, 3, 29080, 31],
			[7300, 10140, 20280, 6490, 4, 34030, 37],
			[9345, 12980, 25960, 8310, 4, 39770, 44],
			[11965, 16615, 33230, 10635, 4, 46440, 53],
			[15315, 21270, 42535, 13610, 4, 54170, 64],
			[19600, 27225, 54445, 17420, 4, 63130, 77]
		],

		//http://t4.answers.travian.com/index.php?aid=184
		TournamentSquare: [
			[1750, 2250, 1530, 240, 1, 3500, 1],
			[2240, 2880, 1960, 305, 1, 4360, 1],
			[2865, 3685, 2505, 395, 1, 5360, 2],
			[3670, 4720, 3210, 505, 1, 6510, 2],
			[4700, 6040, 4105, 645, 1, 7860, 2],
			[6015, 7730, 5255, 825, 1, 9410, 3],
			[7695, 9895, 6730, 1055, 1, 11220, 4],
			[9850, 12665, 8615, 1350, 1, 13320, 4],
			[12610, 16215, 11025, 1730, 1, 15750, 5],
			[16140, 20755, 14110, 2215, 1, 18570, 6],
			[20660, 26565, 18065, 2835, 2, 21840, 7],
			[26445, 34000, 23120, 3625, 2, 25630, 9],
			[33850, 43520, 29595, 4640, 2, 30030, 11],
			[43330, 55705, 37880, 5940, 2, 35140, 13],
			[55460, 71305, 48490, 7605, 2, 41060, 15],
			[70990, 91270, 62065, 9735, 2, 47930, 18],
			[90865, 116825, 79440, 12460, 2, 55900, 22],
			[116305, 149540, 101685, 15950, 2, 65140, 27],
			[148875, 191410, 130160, 20415, 2, 75860, 32],
			[190560, 245005, 166600, 26135, 2, 88300, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=15
		MainBuilding: [
			[70, 40, 60, 20, 2, 2000, 2],
			[90, 50, 75, 25, 1, 2620, 3],
			[115, 65, 100, 35, 1, 3340, 3],
			[145, 85, 125, 40, 1, 4170, 4],
			[190, 105, 160, 55, 1, 5140, 5],
			[240, 135, 205, 70, 2, 6260, 6],
			[310, 175, 265, 90, 2, 7570, 7],
			[395, 225, 340, 115, 2, 9080, 9],
			[505, 290, 430, 145, 2, 10830, 10],
			[645, 370, 555, 185, 2, 12860, 12],
			[825, 470, 710, 235, 2, 15220, 15],
			[1060, 605, 905, 300, 2, 17950, 18],
			[1355, 775, 1160, 385, 2, 21130, 21],
			[1735, 990, 1485, 495, 2, 24810, 26],
			[2220, 1270, 1900, 635, 2, 29080, 31],
			[2840, 1625, 2435, 810, 3, 34030, 37],
			[3635, 2075, 3115, 1040, 3, 39770, 44],
			[4650, 2660, 3990, 1330, 3, 46440, 53],
			[5955, 3405, 5105, 1700, 3, 54170, 64],
			[7620, 4355, 6535, 2180, 3, 63130, 77]
		],

		//http://t4.answers.travian.com/index.php?aid=182
		RallyPoint: [
			[110, 160, 90, 70, 1, 2000, 1],
			[140, 205, 115, 90, 1, 2620, 1],
			[180, 260, 145, 115, 1, 3340, 2],
			[230, 335, 190, 145, 1, 4170, 2],
			[295, 430, 240, 190, 1, 5140, 2],
			[380, 550, 310, 240, 1, 6260, 3],
			[485, 705, 395, 310, 1, 7570, 4],
			[620, 900, 505, 395, 1, 9080, 4],
			[795, 1155, 650, 505, 1, 10830, 5],
			[1015, 1475, 830, 645, 1, 12860, 6],
			[1300, 1890, 1065, 825, 2, 15220, 7],
			[1660, 2420, 1360, 1060, 2, 17950, 9],
			[2130, 3095, 1740, 1355, 2, 21130, 11],
			[2725, 3960, 2230, 1735, 2, 24810, 13],
			[3485, 5070, 2850, 2220, 2, 29080, 15],
			[4460, 6490, 3650, 2840, 2, 34030, 18],
			[5710, 8310, 4675, 3635, 2, 39770, 22],
			[7310, 10635, 5980, 4650, 2, 46440, 27],
			[9360, 13610, 7655, 5955, 2, 54170, 32],
			[11980, 17420, 9800, 7620, 2, 63130, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=16
		Marketplace: [
			[80, 70, 120, 70, 4, 1800, 4],
			[100, 90, 155, 90, 2, 2390, 4],
			[130, 115, 195, 115, 2, 3070, 5],
			[170, 145, 250, 145, 2, 3860, 6],
			[215, 190, 320, 190, 2, 4780, 7],
			[275, 240, 410, 240, 3, 5840, 9],
			[350, 310, 530, 310, 3, 7080, 11],
			[450, 395, 675, 395, 3, 8510, 13],
			[575, 505, 865, 505, 3, 10170, 15],
			[740, 645, 1105, 645, 3, 12100, 19],
			[945, 825, 1415, 825, 3, 14340, 22],
			[1210, 1060, 1815, 1060, 3, 16930, 27],
			[1545, 1355, 2320, 1355, 3, 19940, 32],
			[1980, 1735, 2970, 1735, 3, 23430, 39],
			[2535, 2220, 3805, 2220, 3, 27480, 46],
			[3245, 2840, 4870, 2840, 4, 32180, 55],
			[4155, 3635, 6230, 3635, 4, 37620, 67],
			[5315, 4650, 7975, 4650, 4, 43940, 80],
			[6805, 5955, 10210, 5955, 4, 51270, 96],
			[8710, 7620, 13065, 7620, 4, 59780, 115]
		],

		//http://t4.answers.travian.com/index.php?aid=4
		Embassy: [
			[180, 130, 150, 80, 3, 2000, 5],
			[230, 165, 190, 100, 2, 2620, 6],
			[295, 215, 245, 130, 2, 3340, 7],
			[375, 275, 315, 170, 2, 4170, 8],
			[485, 350, 405, 215, 2, 5140, 10],
			[620, 445, 515, 275, 2, 6260, 12],
			[790, 570, 660, 350, 2, 7570, 14],
			[1015, 730, 845, 450, 2, 9080, 17],
			[1295, 935, 1080, 575, 2, 10830, 21],
			[1660, 1200, 1385, 740, 2, 12860, 25],
			[2125, 1535, 1770, 945, 3, 15220, 30],
			[2720, 1965, 2265, 1210, 3, 17950, 36],
			[3480, 2515, 2900, 1545, 3, 21130, 43],
			[4455, 3220, 3715, 1980, 3, 24810, 51],
			[5705, 4120, 4755, 2535, 3, 29080, 62],
			[7300, 5275, 6085, 3245, 3, 34030, 74],
			[9345, 6750, 7790, 4155, 3, 39770, 89],
			[11965, 8640, 9970, 5315, 3, 46440, 106],
			[15315, 11060, 12760, 6805, 3, 54170, 128],
			[19600, 14155, 16335, 8710, 3, 63130, 153]
		],

		//http://t4.answers.travian.com/index.php?aid=77
		Barracks: [
			[210, 140, 260, 120, 4, 2000, 1],
			[270, 180, 335, 155, 2, 2620, 1],
			[345, 230, 425, 195, 2, 3340, 2],
			[440, 295, 545, 250, 2, 4170, 2],
			[565, 375, 700, 320, 2, 5140, 2],
			[720, 480, 895, 410, 3, 6260, 3],
			[925, 615, 1145, 530, 3, 7570, 4],
			[1180, 790, 1465, 675, 3, 9080, 4],
			[1515, 1010, 1875, 865, 3, 10830, 5],
			[1935, 1290, 2400, 1105, 3, 12860, 6],
			[2480, 1655, 3070, 1415, 3, 15220, 7],
			[3175, 2115, 3930, 1815, 3, 17950, 9],
			[4060, 2710, 5030, 2320, 3, 21130, 11],
			[5200, 3465, 6435, 2970, 3, 24810, 13],
			[6655, 4435, 8240, 3805, 3, 29080, 15],
			[8520, 5680, 10545, 4870, 4, 34030, 18],
			[10905, 7270, 13500, 6230, 4, 39770, 22],
			[13955, 9305, 17280, 7975, 4, 46440, 27],
			[17865, 11910, 22120, 10210, 4, 54170, 32],
			[22865, 15245, 28310, 13065, 4, 63130, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=183
		Stable: [
			[260, 140, 220, 100, 5, 2200, 2],
			[335, 180, 280, 130, 3, 2850, 3],
			[425, 230, 360, 165, 3, 3610, 3],
			[545, 295, 460, 210, 3, 4490, 4],
			[700, 375, 590, 270, 3, 5500, 5],
			[895, 480, 755, 345, 3, 6680, 6],
			[1145, 615, 970, 440, 3, 8050, 7],
			[1465, 790, 1240, 565, 3, 9640, 9],
			[1875, 1010, 1585, 720, 3, 11480, 10],
			[2400, 1290, 2030, 920, 3, 13620, 12],
			[3070, 1655, 2595, 1180, 4, 16100, 15],
			[3930, 2115, 3325, 1510, 4, 18980, 18],
			[5030, 2710, 4255, 1935, 4, 22310, 21],
			[6435, 3465, 5445, 2475, 4, 26180, 26],
			[8240, 4435, 6970, 3170, 4, 30670, 31],
			[10545, 5680, 8925, 4055, 4, 35880, 37],
			[13500, 7270, 11425, 5190, 4, 41920, 44],
			[17280, 9305, 14620, 6645, 4, 48930, 53],
			[22120, 11910, 18715, 8505, 4, 57060, 64],
			[28310, 15245, 23955, 10890, 4, 66490, 77]
		],

		//http://t4.answers.travian.com/index.php?aid=186
		Workshop: [
			[460, 510, 600, 320, 3, 3000, 4],
			[590, 655, 770, 410, 2, 3780, 4],
			[755, 835, 985, 525, 2, 4680, 5],
			[965, 1070, 1260, 670, 2, 5730, 6],
			[1235, 1370, 1610, 860, 2, 6950, 7],
			[1580, 1750, 2060, 1100, 2, 8360, 9],
			[2025, 2245, 2640, 1405, 2, 10000, 11],
			[2590, 2870, 3380, 1800, 2, 11900, 13],
			[3315, 3675, 4325, 2305, 2, 14110, 15],
			[4245, 4705, 5535, 2950, 2, 16660, 19],
			[5430, 6020, 7085, 3780, 3, 19630, 22],
			[6950, 7705, 9065, 4835, 3, 23070, 27],
			[8900, 9865, 11605, 6190, 3, 27060, 32],
			[11390, 12625, 14855, 7925, 3, 31690, 39],
			[14580, 16165, 19015, 10140, 3, 37060, 46],
			[18660, 20690, 24340, 12980, 3, 43290, 55],
			[23885, 26480, 31155, 16615, 3, 50520, 67],
			[30570, 33895, 39875, 21270, 3, 58900, 80],
			[39130, 43385, 51040, 27225, 3, 68630, 96],
			[50090, 55535, 65335, 34845, 3, 79910, 115]
		],

		//http://t4.answers.travian.com/index.php?aid=75
		Academy: [
			[220, 160, 90, 40, 4, 2000, 5],
			[280, 205, 115, 50, 2, 2620, 6],
			[360, 260, 145, 65, 2, 3340, 7],
			[460, 335, 190, 85, 2, 4170, 8],
			[590, 430, 240, 105, 2, 5140, 10],
			[755, 550, 310, 135, 3, 6260, 12],
			[970, 705, 395, 175, 3, 7570, 14],
			[1240, 900, 505, 225, 3, 9080, 17],
			[1585, 1155, 650, 290, 3, 10830, 21],
			[2030, 1475, 830, 370, 3, 12860, 25],
			[2595, 1890, 1065, 470, 3, 15220, 30],
			[3325, 2420, 1360, 605, 3, 17950, 36],
			[4255, 3095, 1740, 775, 3, 21130, 43],
			[5445, 3960, 2230, 990, 3, 24810, 51],
			[6970, 5070, 2850, 1270, 3, 29080, 62],
			[8925, 6490, 3650, 1625, 4, 34030, 74],
			[11425, 8310, 4675, 2075, 4, 39770, 89],
			[14620, 10635, 5980, 2660, 4, 46440, 106],
			[18715, 13610, 7655, 3405, 4, 54170, 128],
			[23955, 17420, 9800, 4355, 4, 63130, 153]
		],

		//http://t4.answers.travian.com/index.php?aid=11
		Cranny: [
			[40, 50, 30, 10, 0, 300, 1],
			[50, 65, 40, 15, 0, 650, 1],
			[65, 80, 50, 15, 0, 1050, 2],
			[85, 105, 65, 20, 0, 1520, 2],
			[105, 135, 80, 25, 0, 2060, 2],
			[135, 170, 105, 35, 1, 2690, 3],
			[175, 220, 130, 45, 1, 3420, 4],
			[225, 280, 170, 55, 1, 4270, 4],
			[290, 360, 215, 70, 1, 5260, 5],
			[370, 460, 275, 90, 1, 6400, 6]
		],

		//http://t4.answers.travian.com/index.php?aid=46
		TownHall: [
			[1250, 1110, 1260, 600, 4, 12500, 6],
			[1600, 1420, 1615, 770, 2, 14800, 7],
			[2050, 1820, 2065, 985, 2, 17470, 9],
			[2620, 2330, 2640, 1260, 2, 20560, 10],
			[3355, 2980, 3380, 1610, 2, 24150, 12],
			[4295, 3815, 4330, 2060, 3, 28320, 15],
			[5500, 4880, 5540, 2640, 3, 33150, 18],
			[7035, 6250, 7095, 3380, 3, 38750, 21],
			[9005, 8000, 9080, 4325, 3, 45250, 26],
			[11530, 10240, 11620, 5535, 3, 52790, 31],
			[14755, 13105, 14875, 7085, 3, 61540, 37],
			[18890, 16775, 19040, 9065, 3, 71690, 45],
			[24180, 21470, 24370, 11605, 3, 83460, 53],
			[30950, 27480, 31195, 14855, 3, 97110, 64],
			[39615, 35175, 39930, 19015, 3, 112950, 77],
			[50705, 45025, 51110, 24340, 4, 131320, 92],
			[64905, 57635, 65425, 31155, 4, 152630, 111],
			[83075, 73770, 83740, 39875, 4, 177350, 133],
			[106340, 94430, 107190, 51040, 4, 206020, 160],
			[136115, 120870, 137200, 65335, 4, 239290, 192]
		],

		//http://t4.answers.travian.com/index.php?aid=18
		Residence: [
			[580, 460, 350, 180, 1, 2000, 2],
			[740, 590, 450, 230, 1, 2620, 3],
			[950, 755, 575, 295, 1, 3340, 3],
			[1215, 965, 735, 375, 1, 4170, 4],
			[1555, 1235, 940, 485, 1, 5140, 5],
			[1995, 1580, 1205, 620, 1, 6260, 6],
			[2550, 2025, 1540, 790, 1, 7570, 7],
			[3265, 2590, 1970, 1015, 1, 9080, 9],
			[4180, 3315, 2520, 1295, 1, 10830, 10],
			[5350, 4245, 3230, 1660, 1, 12860, 12],
			[6845, 5430, 4130, 2125, 2, 15220, 15],
			[8765, 6950, 5290, 2720, 2, 17950, 18],
			[11220, 8900, 6770, 3480, 2, 21130, 21],
			[14360, 11390, 8665, 4455, 2, 24810, 26],
			[18380, 14580, 11090, 5705, 2, 29080, 31],
			[23530, 18660, 14200, 7300, 2, 34030, 37],
			[30115, 23885, 18175, 9345, 2, 39770, 44],
			[38550, 30570, 23260, 11965, 2, 46440, 53],
			[49340, 39130, 29775, 15315, 2, 54170, 64],
			[63155, 50090, 38110, 19600, 2, 63130, 77]
		],

		//http://t4.answers.travian.com/index.php?aid=17
		Palace: [
			[550, 800, 750, 250, 1, 5000, 6],
			[705, 1025, 960, 320, 1, 6100, 7],
			[900, 1310, 1230, 410, 1, 7380, 9],
			[1155, 1680, 1575, 525, 1, 8860, 10],
			[1475, 2145, 2015, 670, 1, 10570, 12],
			[1890, 2750, 2575, 860, 1, 12560, 15],
			[2420, 3520, 3300, 1100, 1, 14880, 18],
			[3095, 4505, 4220, 1405, 1, 17560, 21],
			[3965, 5765, 5405, 1800, 1, 20660, 26],
			[5075, 7380, 6920, 2305, 1, 24270, 31],
			[6495, 9445, 8855, 2950, 2, 28450, 37],
			[8310, 12090, 11335, 3780, 2, 33310, 45],
			[10640, 15475, 14505, 4835, 2, 38940, 53],
			[13615, 19805, 18570, 6190, 2, 45460, 64],
			[17430, 25355, 23770, 7925, 2, 53040, 77],
			[22310, 32450, 30425, 10140, 2, 61830, 92],
			[28560, 41540, 38940, 12980, 2, 72020, 111],
			[36555, 53170, 49845, 16615, 2, 83840, 133],
			[46790, 68055, 63805, 21270, 2, 97550, 160],
			[59890, 87110, 81670, 27225, 2, 113460, 192]
		],

		//http://t4.answers.travian.com/index.php?aid=50
		Treasury: [
			[2880, 2740, 2580, 990, 4, 8000, 7],
			[3630, 3450, 3250, 1245, 2, 9580, 9],
			[4570, 4350, 4095, 1570, 2, 11410, 10],
			[5760, 5480, 5160, 1980, 2, 13540, 12],
			[7260, 6905, 6505, 2495, 2, 16010, 15],
			[9145, 8700, 8195, 3145, 3, 18870, 18],
			[11525, 10965, 10325, 3960, 3, 22180, 21],
			[14520, 13815, 13010, 4990, 3, 26030, 26],
			[18295, 17405, 16390, 6290, 3, 30500, 31],
			[23055, 21930, 20650, 7925, 3, 35680, 37],
			[29045, 27635, 26020, 9985, 3, 41690, 45],
			[36600, 34820, 32785, 12580, 3, 48660, 53],
			[46115, 43875, 41310, 15850, 3, 56740, 64],
			[58105, 55280, 52050, 19975, 3, 66120, 77],
			[73210, 69655, 65585, 25165, 3, 77000, 92],
			[92245, 87760, 82640, 31710, 4, 89620, 111],
			[116230, 110580, 104125, 39955, 4, 104260, 133],
			[146450, 139330, 131195, 50340, 4, 121240, 160],
			[184530, 175560, 165305, 63430, 4, 140940, 192],
			[232505, 221205, 208285, 79925, 4, 163790, 230]
		],

		//http://t4.answers.travian.com/index.php?aid=48
		TradeOffice: [
			[1400, 1330, 1200, 400, 3, 3000, 4],
			[1790, 1700, 1535, 510, 2, 3780, 4],
			[2295, 2180, 1965, 655, 2, 4680, 5],
			[2935, 2790, 2515, 840, 2, 5730, 6],
			[3760, 3570, 3220, 1075, 2, 6950, 7],
			[4810, 4570, 4125, 1375, 2, 8360, 9],
			[6155, 5850, 5280, 1760, 2, 10000, 11],
			[7880, 7485, 6755, 2250, 2, 11900, 13],
			[10090, 9585, 8645, 2880, 2, 14110, 15],
			[12915, 12265, 11070, 3690, 2, 16660, 19],
			[16530, 15700, 14165, 4720, 3, 19630, 22],
			[21155, 20100, 18135, 6045, 3, 23070, 27],
			[27080, 25725, 23210, 7735, 3, 27060, 32],
			[34660, 32930, 29710, 9905, 3, 31690, 39],
			[44370, 42150, 38030, 12675, 3, 37060, 46],
			[56790, 53950, 48680, 16225, 3, 43290, 55],
			[72690, 69060, 62310, 20770, 3, 50520, 67],
			[93045, 88395, 79755, 26585, 3, 58900, 80],
			[119100, 113145, 102085, 34030, 3, 68630, 96],
			[152445, 144825, 130670, 43555, 3, 79910, 115]
		],

		//http://t4.answers.travian.com/index.php?aid=178
		GreatBarracks: [
			[630, 420, 780, 360, 4, 2000, 1],
			[805, 540, 1000, 460, 2, 2620, 1],
			[1030, 690, 1280, 590, 2, 3340, 2],
			[1320, 880, 1635, 755, 2, 4170, 2],
			[1690, 1125, 2095, 965, 2, 5140, 2],
			[2165, 1445, 2680, 1235, 3, 6260, 3],
			[2770, 1845, 3430, 1585, 3, 7570, 4],
			[3545, 2365, 4390, 2025, 3, 9080, 4],
			[4540, 3025, 5620, 2595, 3, 10830, 5],
			[5810, 3875, 7195, 3320, 3, 12860, 6],
			[7440, 4960, 9210, 4250, 3, 15220, 7],
			[9520, 6345, 11785, 5440, 3, 17950, 9],
			[12185, 8125, 15085, 6965, 3, 21130, 11],
			[15600, 10400, 19310, 8915, 3, 24810, 13],
			[19965, 13310, 24720, 11410, 3, 29080, 15],
			[25555, 17035, 31640, 14605, 4, 34030, 18],
			[32710, 21810, 40500, 18690, 4, 39770, 22],
			[41870, 27915, 51840, 23925, 4, 46440, 27],
			[53595, 35730, 66355, 30625, 4, 54170, 32],
			[68600, 45735, 84935, 39200, 4, 63130, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=179
		GreatStable: [
			[780, 420, 660, 300, 5, 2200, 2],
			[1000, 540, 845, 385, 3, 2850, 3],
			[1280, 690, 1080, 490, 3, 3610, 3],
			[1635, 880, 1385, 630, 3, 4490, 4],
			[2095, 1125, 1770, 805, 3, 5500, 5],
			[2680, 1445, 2270, 1030, 3, 6680, 6],
			[3430, 1845, 2905, 1320, 3, 8050, 7],
			[4390, 2365, 3715, 1690, 3, 9640, 9],
			[5620, 3025, 4755, 2160, 3, 11480, 10],
			[7195, 3875, 6085, 2765, 3, 13620, 12],
			[9210, 4960, 7790, 3540, 4, 16100, 15],
			[11785, 6345, 9975, 4535, 4, 18980, 18],
			[15085, 8125, 12765, 5805, 4, 22310, 21],
			[19310, 10400, 16340, 7430, 4, 26180, 26],
			[24720, 13310, 20915, 9505, 4, 30670, 31],
			[31640, 17035, 26775, 12170, 4, 35880, 37],
			[40500, 21810, 34270, 15575, 4, 41920, 44],
			[51840, 27915, 43865, 19940, 4, 48930, 53],
			[66355, 35730, 56145, 25520, 4, 57060, 64],
			[84935, 45735, 71870, 32665, 4, 66490, 77]
		],

		//http://t4.answers.travian.com/index.php?aid=85
		CityWall: [
			[70, 90, 170, 70, 0, 2000, 1],
			[90, 115, 220, 90, 0, 2620, 1],
			[115, 145, 280, 115, 0, 3340, 2],
			[145, 190, 355, 145, 0, 4170, 2],
			[190, 240, 455, 190, 0, 5140, 2],
			[240, 310, 585, 240, 1, 6260, 3],
			[310, 395, 750, 310, 1, 7570, 4],
			[395, 505, 955, 395, 1, 9080, 4],
			[505, 650, 1225, 505, 1, 10830, 5],
			[645, 830, 1570, 645, 1, 12860, 6],
			[825, 1065, 2005, 825, 1, 15220, 7],
			[1060, 1360, 2570, 1060, 1, 17950, 9],
			[1355, 1740, 3290, 1355, 1, 21130, 11],
			[1735, 2230, 4210, 1735, 1, 24810, 13],
			[2220, 2850, 5390, 2220, 1, 29080, 15],
			[2840, 3650, 6895, 2840, 2, 34030, 18],
			[3635, 4675, 8825, 3635, 2, 39770, 22],
			[4650, 5980, 11300, 4650, 2, 46440, 27],
			[5955, 7655, 14460, 5955, 2, 54170, 32],
			[7620, 9800, 18510, 7620, 2, 63130, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=86
		EarthWall: [
			[120, 200, 0, 80, 0, 2000, 1],
			[155, 255, 0, 100, 0, 2620, 1],
			[195, 330, 0, 130, 0, 3340, 2],
			[250, 420, 0, 170, 0, 4170, 2],
			[320, 535, 0, 215, 0, 5140, 2],
			[410, 685, 0, 275, 1, 6260, 3],
			[530, 880, 0, 350, 1, 7570, 4],
			[675, 1125, 0, 450, 1, 9080, 4],
			[865, 1440, 0, 575, 1, 10830, 5],
			[1105, 1845, 0, 740, 1, 12860, 6],
			[1415, 2360, 0, 945, 1, 15220, 7],
			[1815, 3020, 0, 1210, 1, 17950, 9],
			[2320, 3870, 0, 1545, 1, 21130, 11],
			[2970, 4950, 0, 1980, 1, 24810, 13],
			[3805, 6340, 0, 2535, 1, 29080, 15],
			[4870, 8115, 0, 3245, 2, 34030, 18],
			[6230, 10385, 0, 4155, 2, 39770, 22],
			[7975, 13290, 0, 5315, 2, 46440, 27],
			[10210, 17015, 0, 6805, 2, 54170, 32],
			[13065, 21780, 0, 8710, 2, 63130, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=181
		Palisade: [
			[160, 100, 80, 60, 0, 2000, 1],
			[205, 130, 100, 75, 0, 2620, 1],
			[260, 165, 130, 100, 0, 3340, 2],
			[335, 210, 170, 125, 0, 4170, 2],
			[430, 270, 215, 160, 0, 5140, 2],
			[550, 345, 275, 205, 1, 6260, 3],
			[705, 440, 350, 265, 1, 7570, 4],
			[900, 565, 450, 340, 1, 9080, 4],
			[1155, 720, 575, 430, 1, 10830, 5],
			[1475, 920, 740, 555, 1, 12860, 6],
			[1890, 1180, 945, 710, 1, 15220, 7],
			[2420, 1510, 1210, 905, 1, 17950, 9],
			[3095, 1935, 1545, 1160, 1, 21130, 11],
			[3960, 2475, 1980, 1485, 1, 24810, 13],
			[5070, 3170, 2535, 1900, 1, 29080, 15],
			[6490, 4055, 3245, 2435, 2, 34030, 18],
			[8310, 5190, 4155, 3115, 2, 39770, 22],
			[10635, 6645, 5315, 3990, 2, 46440, 27],
			[13610, 8505, 6805, 5105, 2, 54170, 32],
			[17420, 10890, 8710, 6535, 2, 63130, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=19
		StonemasonsLodge: [
			[155, 130, 125, 70, 2, 2200, 1],
			[200, 165, 160, 90, 1, 3150, 1],
			[255, 215, 205, 115, 1, 4260, 2],
			[325, 275, 260, 145, 1, 5540, 2],
			[415, 350, 335, 190, 1, 7020, 2],
			[535, 445, 430, 240, 2, 8750, 3],
			[680, 570, 550, 310, 2, 10750, 4],
			[875, 730, 705, 395, 2, 13070, 4],
			[1115, 935, 900, 505, 2, 15760, 5],
			[1430, 1200, 1155, 645, 2, 18880, 6],
			[1830, 1535, 1475, 825, 2, 22500, 7],
			[2340, 1965, 1890, 1060, 2, 26700, 9],
			[3000, 2515, 2420, 1355, 2, 31570, 11],
			[3840, 3220, 3095, 1735, 2, 37220, 13],
			[4910, 4120, 3960, 2220, 2, 43780, 15],
			[6290, 5275, 5070, 2840, 3, 51380, 18],
			[8050, 6750, 6490, 3635, 3, 60200, 22],
			[10300, 8640, 8310, 4650, 3, 70430, 27],
			[13185, 11060, 10635, 5955, 3, 82300, 32],
			[16880, 14155, 13610, 7620, 3, 96070, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=9
		Brewery: [
			[1460, 930, 1250, 1740, 6, 8000, 5],
			[2045, 1300, 1750, 2435, 3, 9880, 6],
			[2860, 1825, 2450, 3410, 3, 12060, 7],
			[4005, 2550, 3430, 4775, 3, 14590, 8],
			[5610, 3575, 4800, 6685, 3, 17530, 10],
			[7850, 5000, 6725, 9360, 4, 20930, 12],
			[10995, 7000, 9410, 13100, 4, 24880, 14],
			[15390, 9805, 13175, 18340, 4, 29460, 17],
			[21545, 13725, 18445, 25680, 4, 34770, 21],
			[30165, 19215, 25825, 35950, 4, 40930, 25]
		],

		//http://t4.answers.travian.com/index.php?aid=185
		Trapper: [
			[80, 120, 70, 90, 4, 2000, 1],
			[100, 155, 90, 115, 2, 2320, 1],
			[130, 195, 115, 145, 2, 2690, 2],
			[170, 250, 145, 190, 2, 3120, 2],
			[215, 320, 190, 240, 2, 3620, 2],
			[275, 410, 240, 310, 3, 4200, 3],
			[350, 530, 310, 395, 3, 4870, 4],
			[450, 675, 395, 505, 3, 5650, 4],
			[575, 865, 505, 650, 3, 6560, 5],
			[740, 1105, 645, 830, 3, 7610, 6],
			[945, 1415, 825, 1065, 3, 8820, 7],
			[1210, 1815, 1060, 1360, 3, 10230, 9],
			[1545, 2320, 1355, 1740, 3, 11870, 11],
			[1980, 2970, 1735, 2230, 3, 13770, 13],
			[2535, 3805, 2220, 2850, 3, 15980, 15],
			[3245, 4870, 2840, 3650, 4, 18530, 18],
			[4155, 6230, 3635, 4675, 4, 21500, 22],
			[5315, 7975, 4650, 5980, 4, 24940, 27],
			[6805, 10210, 5955, 7655, 4, 28930, 32],
			[8710, 13065, 7620, 9800, 4, 33550, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=180
		HerosMansion: [
			[700, 670, 700, 240, 2, 2300, 1],
			[930, 890, 930, 320, 1, 2670, 1],
			[1240, 1185, 1240, 425, 1, 3090, 2],
			[1645, 1575, 1645, 565, 1, 3590, 2],
			[2190, 2095, 2190, 750, 1, 4160, 2],
			[2915, 2790, 2915, 1000, 2, 4830, 3],
			[3875, 3710, 3875, 1330, 2, 5600, 4],
			[5155, 4930, 5155, 1765, 2, 6500, 4],
			[6855, 6560, 6855, 2350, 2, 7540, 5],
			[9115, 8725, 9115, 3125, 2, 8750, 6],
			[12125, 11605, 12125, 4155, 2, 10150, 7],
			[16125, 15435, 16125, 5530, 2, 11770, 9],
			[21445, 20525, 21445, 7350, 2, 13650, 11],
			[28520, 27300, 28520, 9780, 2, 15840, 13],
			[37935, 36310, 37935, 13005, 2, 18370, 15],
			[50450, 48290, 50450, 17300, 3, 21310, 18],
			[67100, 64225, 67100, 23005, 3, 24720, 22],
			[89245, 85420, 89245, 30600, 3, 28680, 27],
			[118695, 113605, 118695, 40695, 3, 33260, 32],
			[157865, 151095, 157865, 54125, 3, 38590, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=13
		GreatWarehouse: [
			[650, 800, 450, 200, 1, 9000, 1],
			[830, 1025, 575, 255, 1, 10740, 1],
			[1065, 1310, 735, 330, 1, 12760, 2],
			[1365, 1680, 945, 420, 1, 15100, 2],
			[1745, 2145, 1210, 535, 1, 17820, 2],
			[2235, 2750, 1545, 685, 1, 20970, 3],
			[2860, 3520, 1980, 880, 1, 24620, 4],
			[3660, 4505, 2535, 1125, 1, 28860, 4],
			[4685, 5765, 3245, 1440, 1, 33780, 5],
			[5995, 7380, 4150, 1845, 1, 39480, 6],
			[7675, 9445, 5315, 2360, 2, 46100, 7],
			[9825, 12090, 6800, 3020, 2, 53780, 9],
			[12575, 15475, 8705, 3870, 2, 62680, 11],
			[16095, 19805, 11140, 4950, 2, 73010, 13],
			[20600, 25355, 14260, 6340, 2, 84990, 15],
			[26365, 32450, 18255, 8115, 2, 98890, 18],
			[33750, 41540, 23365, 10385, 2, 115010, 22],
			[43200, 53170, 29910, 13290, 2, 133710, 27],
			[55295, 68055, 38280, 17015, 2, 155400, 32],
			[70780, 87110, 49000, 21780, 2, 180570, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=12
		GreatGranary: [
			[400, 500, 350, 100, 1, 7000, 1],
			[510, 640, 450, 130, 1, 8420, 1],
			[655, 820, 575, 165, 1, 10070, 2],
			[840, 1050, 735, 210, 1, 11980, 2],
			[1075, 1340, 940, 270, 1, 14190, 2],
			[1375, 1720, 1205, 345, 1, 16770, 3],
			[1760, 2200, 1540, 440, 1, 19750, 4],
			[2250, 2815, 1970, 565, 1, 23210, 4],
			[2880, 3605, 2520, 720, 1, 27220, 5],
			[3690, 4610, 3230, 920, 1, 31880, 6],
			[4720, 5905, 4130, 1180, 2, 37280, 7],
			[6045, 7555, 5290, 1510, 2, 43540, 9],
			[7735, 9670, 6770, 1935, 2, 50810, 11],
			[9905, 12380, 8665, 2475, 2, 59240, 13],
			[12675, 15845, 11090, 3170, 2, 69010, 15],
			[16225, 20280, 14200, 4055, 2, 80360, 18],
			[20770, 25960, 18175, 5190, 2, 93510, 22],
			[26585, 33230, 23260, 6645, 2, 108780, 27],
			[34030, 42535, 29775, 8505, 2, 126480, 32],
			[43555, 54445, 38110, 10890, 2, 147020, 38]
		],

		//http://t4.answers.travian.com/index.php?aid=73
		WonderoftheWorld: [
			[66700, 69050, 72200, 13200, 1, 18000, 0],
			[68535, 70950, 74185, 13565, 1, 18850, 0],
			[70420, 72900, 76225, 13935, 1, 19720, 0],
			[72355, 74905, 78320, 14320, 1, 20590, 0],
			[74345, 76965, 80475, 14715, 1, 21480, 0],
			[76390, 79080, 82690, 15120, 1, 22380, 0],
			[78490, 81255, 84965, 15535, 1, 23290, 0],
			[80650, 83490, 87300, 15960, 1, 24220, 0],
			[82865, 85785, 89700, 16400, 1, 25160, 0],
			[85145, 88145, 92165, 16850, 1, 26110, 0],
			[87485, 90570, 94700, 17315, 2, 27080, 0],
			[89895, 93060, 97305, 17790, 2, 28060, 0],
			[92365, 95620, 99980, 18280, 2, 29050, 0],
			[94905, 98250, 102730, 18780, 2, 30060, 0],
			[97515, 100950, 105555, 19300, 2, 31080, 0],
			[100195, 103725, 108460, 19830, 2, 32110, 0],
			[102950, 106580, 111440, 20375, 2, 33160, 0],
			[105785, 109510, 114505, 20935, 2, 34230, 0],
			[108690, 112520, 117655, 21510, 2, 35300, 0],
			[111680, 115615, 120890, 22100, 2, 36400, 0],
			[114755, 118795, 124215, 22710, 3, 37510, 0],
			[117910, 122060, 127630, 23335, 3, 38630, 0],
			[121150, 125420, 131140, 23975, 3, 39770, 0],
			[124480, 128870, 134745, 24635, 3, 40930, 0],
			[127905, 132410, 138455, 25315, 3, 42100, 0],
			[131425, 136055, 142260, 26010, 3, 43290, 0],
			[135035, 139795, 146170, 26725, 3, 44500, 0],
			[138750, 143640, 150190, 27460, 3, 45720, 0],
			[142565, 147590, 154320, 28215, 3, 46960, 0],
			[146485, 151650, 158565, 28990, 3, 48220, 0],
			[150515, 155820, 162925, 29785, 4, 49500, 0],
			[154655, 160105, 167405, 30605, 4, 50790, 0],
			[158910, 164505, 172010, 31450, 4, 52100, 0],
			[163275, 169030, 176740, 32315, 4, 53430, 0],
			[167770, 173680, 181600, 33200, 4, 54780, 0],
			[172380, 178455, 186595, 34115, 4, 56140, 0],
			[177120, 183360, 191725, 35055, 4, 57530, 0],
			[181995, 188405, 197000, 36015, 4, 58940, 0],
			[186995, 193585, 202415, 37005, 4, 60360, 0],
			[192140, 198910, 207985, 38025, 4, 61810, 0],
			[197425, 204380, 213705, 39070, 5, 63270, 0],
			[202855, 210000, 219580, 40145, 5, 64760, 0],
			[208430, 215775, 225620, 41250, 5, 66260, 0],
			[214165, 221710, 231825, 42385, 5, 67790, 0],
			[220055, 227805, 238200, 43550, 5, 69340, 0],
			[226105, 234070, 244750, 44745, 5, 70910, 0],
			[232320, 240505, 251480, 45975, 5, 72500, 0],
			[238710, 247120, 258395, 47240, 5, 74120, 0],
			[245275, 253915, 265500, 48540, 5, 75760, 0],
			[252020, 260900, 272800, 49875, 5, 77420, 0],
			[258950, 268075, 280305, 51245, 6, 79100, 0],
			[266070, 275445, 288010, 52655, 6, 80810, 0],
			[273390, 283020, 295930, 54105, 6, 82540, 0],
			[280905, 290805, 304070, 55590, 6, 84290, 0],
			[288630, 298800, 312430, 57120, 6, 86070, 0],
			[296570, 307020, 321025, 58690, 6, 87880, 0],
			[304725, 315460, 329850, 60305, 6, 89710, 0],
			[313105, 324135, 338925, 61965, 6, 91570, 0],
			[321715, 333050, 348245, 63670, 6, 93450, 0],
			[330565, 342210, 357820, 65420, 6, 95360, 0],
			[339655, 351620, 367660, 67220, 7, 97290, 0],
			[348995, 361290, 377770, 69065, 7, 99250, 0],
			[358590, 371225, 388160, 70965, 7, 101240, 0],
			[368450, 381435, 398835, 72915, 7, 103260, 0],
			[378585, 391925, 409800, 74920, 7, 105310, 0],
			[388995, 402700, 421070, 76985, 7, 107380, 0],
			[399695, 413775, 432650, 79100, 7, 109480, 0],
			[410685, 425155, 444550, 81275, 7, 111620, 0],
			[421980, 436845, 456775, 83510, 7, 113780, 0],
			[433585, 448860, 469335, 85805, 7, 115970, 0],
			[445505, 461205, 482240, 88165, 8, 118200, 0],
			[457760, 473885, 495505, 90590, 8, 120450, 0],
			[470345, 486920, 509130, 93080, 8, 122740, 0],
			[483280, 500310, 523130, 95640, 8, 125060, 0],
			[496570, 514065, 537520, 98270, 8, 127410, 0],
			[510225, 528205, 552300, 100975, 8, 129790, 0],
			[524260, 542730, 567490, 103750, 8, 132210, 0],
			[538675, 557655, 583095, 106605, 8, 134660, 0],
			[553490, 572990, 599130, 109535, 8, 137140, 0],
			[568710, 588745, 615605, 112550, 8, 139660, 0],
			[584350, 604935, 632535, 115645, 9, 142220, 0],
			[600420, 621575, 649930, 118825, 9, 144810, 0],
			[616930, 638665, 667800, 122090, 9, 147440, 0],
			[633895, 656230, 686165, 125450, 9, 150100, 0],
			[651330, 674275, 705035, 128900, 9, 152800, 0],
			[669240, 692820, 724425, 132445, 9, 155540, 0],
			[687645, 711870, 744345, 136085, 9, 158320, 0],
			[706555, 731445, 764815, 139830, 9, 161140, 0],
			[725985, 751560, 785850, 143675, 9, 163990, 0],
			[745950, 772230, 807460, 147625, 9, 166890, 0],
			[766460, 793465, 829665, 151685, 10, 169820, 0],
			[787540, 815285, 852480, 155855, 10, 172800, 0],
			[809195, 837705, 875920, 160140, 10, 175820, 0],
			[831450, 860745, 900010, 164545, 10, 178880, 0],
			[854315, 884415, 924760, 169070, 10, 181990, 0],
			[877810, 908735, 950190, 173720, 10, 185130, 0],
			[901950, 933725, 976320, 178495, 10, 188330, 0],
			[926750, 959405, 1000000, 183405, 10, 191560, 0],
			[952235, 985785, 1000000, 188450, 10, 194840, 0],
			[1000000, 1000000, 1000000, 193630, 10, 198170, 0]
		],

		//http://t4.answers.travian.com/index.php?aid=14
		HorseDrinkingTrough: [
			[780, 420, 660, 540, 5, 2200, 4],
			[1000, 540, 845, 690, 3, 3150, 4],
			[1280, 690, 1080, 885, 3, 4260, 5],
			[1635, 880, 1385, 1130, 3, 5540, 6],
			[2095, 1125, 1770, 1450, 3, 7020, 7],
			[2680, 1445, 2270, 1855, 3, 8750, 9],
			[3430, 1845, 2905, 2375, 3, 10750, 11],
			[4390, 2365, 3715, 3040, 3, 13070, 13],
			[5620, 3025, 4755, 3890, 3, 15760, 15],
			[7195, 3875, 6085, 4980, 3, 18880, 19],
			[9210, 4960, 7790, 6375, 4, 22500, 22],
			[11785, 6345, 9975, 8160, 4, 26700, 27],
			[15085, 8125, 12765, 10445, 4, 31570, 32],
			[19310, 10400, 16340, 13370, 4, 37220, 39],
			[24720, 13310, 20915, 17115, 4, 43780, 46],
			[31640, 17035, 26775, 21905, 4, 51380, 55],
			[40500, 21810, 34270, 28040, 4, 60200, 67],
			[51840, 27915, 43865, 35890, 4, 70430, 80],
			[66355, 35730, 56145, 45940, 4, 82300, 96],
			[84935, 45735, 71870, 58800, 4, 96070, 115]
		]
	}
};